package javax.swing.event;

import javax.swing.tree.TreePath;
import java.util.EventObject;

public class TreeModelEvent extends EventObject
{
    protected TreePath path;
    protected int[] childIndices;
    protected Object[] children;
    
    public TreeModelEvent(Object o, Object[] path, int[] array, Object[] array2) {
        this(o, (path == null) ? null : new TreePath(path), array, array2);
    }
    
    public TreeModelEvent(Object source, TreePath path, int[] childIndices, Object[] children) {
        super(source);
        this.path = path;
        this.childIndices = childIndices;
        this.children = children;
    }
    
    public TreeModelEvent(Object o, Object[] path) {
        this(o, (path == null) ? null : new TreePath(path));
    }
    
    public TreeModelEvent(Object source, TreePath path) {
        super(source);
        this.path = path;
        this.childIndices = new int[0];
    }
    
    public TreePath getTreePath() {
        return this.path;
    }
    
    public Object[] getPath() {
        if (this.path != null) {
            return this.path.getPath();
        }
        return null;
    }
    
    public Object[] getChildren() {
        if (this.children != null) {
            int length = this.children.length;
            Object[] array = new Object[length];
            System.arraycopy(this.children, 0, array, 0, length);
            return array;
        }
        return null;
    }
    
    public int[] getChildIndices() {
        if (this.childIndices != null) {
            int length = this.childIndices.length;
            int[] array = new int[length];
            System.arraycopy(this.childIndices, 0, array, 0, length);
            return array;
        }
        return null;
    }
    
    @Override
    public String toString() {
        StringBuffer sb = new StringBuffer();
        sb.append(this.getClass().getName() + " " + Integer.toString(this.hashCode()));
        if (this.path != null) {
            sb.append(" path " + this.path);
        }
        if (this.childIndices != null) {
            sb.append(" indices [ ");
            for (int i = 0; i < this.childIndices.length; ++i) {
                sb.append(Integer.toString(this.childIndices[i]) + " ");
            }
            sb.append("]");
        }
        if (this.children != null) {
            sb.append(" children [ ");
            for (int j = 0; j < this.children.length; ++j) {
                sb.append(this.children[j] + " ");
            }
            sb.append("]");
        }
        return sb.toString();
    }
}
